@@ -1,8 +1,7 @@
 #!/bin/bash
 # 自动配置深度学习环境变量/自动挑选显卡/自动后台日志
 py=$(which python)
-# spy=${py%bin*}lib/python*/site-packages/tsc_auto/set_gpu.py  # set_gpu.py脚本所在目录绝对路径
-spy=set_gpu.py  # set_gpu.py脚本所在目录绝对路径
+spy=${py%bin*}lib/python*/site-packages/tsc_auto/set_gpu.py  # set_gpu.py脚本所在目录绝对路径
 # function 与mac不兼容
 function version_gt() { test "$(echo "$@" | tr " " "\n" | sort -V | head -n 1)" != "$1"; }
 function version_le() { test "$(echo "$@" | tr " " "\n" | sort -V | head -n 1)" == "$1"; }
@@ -88,6 +87,9 @@ while [[ $# -gt 0 ]]; do
       help=true
       shift # past argument
       ;;
+      *)  # 其他情况
+      shift # past argument
+      ;;
   esac
 done
 
@@ -102,7 +104,7 @@ if [ $help ]; then
   echo -e '-n\t不指定gpu编号,防止和其他指定调度程序冲突'
   echo -e '-d\t指定gpu编号设备,即设置CUDA_VISIBLE_DEVICES,优先级在-n之上,不能有空格'
   echo -e '-h, --help\t查看帮助'
-  echo -e '说明: 使用gpu必须在对应conda环境下执行, 深度学习框架要安装在默认路径, py脚本路径和cuda路径需要适配'
+  echo -e '说明: 使用gpu必须在对应conda环境下执行, 深度学习框架要安装在默认路径, cuda路径需要适配'
   exit 0
 fi
 
@@ -187,7 +189,7 @@ if [ $deep ]; then  # 配置环境变量
   fi
 
   cudap=~/cuda/$cuda/lib64:~/cuda/$cuda/extras/CUPTI/lib64  # cuda 路径根据需要修改
-  export LD_LIBRARY_PATH=~/anaconda3/lib:$cudap  # cuda 路径根据需要修改
+  export LD_LIBRARY_PATH=${py%bin*}lib:$cudap  # cuda 路径根据需要修改
   if !(isexist $PATH ~/cuda/$cuda/bin); then
     export PATH=~/cuda/$cuda/bin:$PATH  # >=tf2.3 ptxas 所需
   fi
